[![Latest Version](https://img.shields.io/pypi/v/typerdrive?label=pypi-version&logo=python&style=plastic)](https://pypi.org/project/typerdrive/)
[![Python Versions](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Fdusktreader%2Ftyperdrive%2Fmain%2Fpyproject.toml&style=plastic&logo=python&label=python-versions)](https://www.python.org/)
[![Build Status](https://github.com/dusktreader/typerdrive/actions/workflows/main.yml/badge.svg)](https://github.com/dusktreader/typerdrive/actions/workflows/main.yml)
[![Documentation Status](https://github.com/dusktreader/typerdrive/actions/workflows/docs.yml/badge.svg)](https://dusktreader.github.io/typerdrive/)


> [!IMPORTANT]
> I'm looking for a job right now! If you know of any openings that match my skill-set, please let me know! You can
> read my resume over at my [cv site](https://cv.dusktreader.dev). Thanks!


![typerdrive-logo](https://github.com/dusktreader/typerdrive/blob/main/docs/source/images/logo-dark.png)

_Boost your command-line workflows to lightspeed_


## Features

- [Settings management & commands](https://dusktreader.github.io/typerdrive/features/settings)
- [Cache management & commands](https://dusktreader.github.io/typerdrive/features/cache)
- [User-friendly error handling](https://dusktreader.github.io/typerdrive/features/exceptions)
- [Powered Up API clients](https://dusktreader.github.io/typerdrive/features/client)


## Super-quick Start

Requires: Python 3.12 to 3.13

Install through pip:

```bash
pip install typerdrive
```


## Documentation

The complete documentation can be found at the
[typerdrive home page](https://dusktreader.github.io/typerdrive)


## Demo

To see the features in action, you can run the demo in an isolated environment with `uv`:

```
uvx --from=typerdrive[demo] typerdrive-demo
```
